#!/bin/sh
# -----------------------------------------------------------------------------
# Sets command line options for WASCE.
#
# This script is invoked by Apache Geronimo scripts or stand-alone
# WASCE sample programs.
# -----------------------------------------------------------------------------
# BEGIN: RLS 20170526 WI 71684 Enable Optim Manager to run with MD5 Java Security
# This script is called at startup and shut down of WAS-CE
# At startup, replace the original java.security file with a revised one
# At shutdown, restore the original java.security

# Determine if WAS-CE is running...
_CNT="`ps -ef | grep -c geronimo`"

if [ ${_CNT} -gt 3 ] ; then
    echo "WAS-CE is running. CNT= ${_CNT}"
    # Determine if the java.security file was previously overwritten
    if [ -f ../../../jdk/jre/lib/security/java.security.orig ] ; then
        # Back up the original java.security file
        # echo "Restoring  ../../../jdk/jre/lib/security/java.security.orig"

        # Remove the overridden file java.security
        rm -f ../../../jdk/jre/lib/security/java.security
        # Restore the original java.secrity file
        mv ../../../jdk/jre/lib/security/java.security.orig ../../../jdk/jre/lib/security/java.security
    fi
else
    echo "WAS-CE is not running. CNT= ${_CNT}"

    # Sanity check... ensure new security file exists
    if [ -f ../../../was-ce/java_was-ce.security ] ; then
        # echo "Found ../../../was-ce/java_was-ce.security"
        # Ensure the java.security file was not previously overwritten
        if [ ! -f ../../../jdk/jre/lib/security/java.security.orig ] ; then
            # Back up the original java.security file
            # echo "Backing up  ../../../jdk/jre/lib/security/java.security"

            mv ../../../jdk/jre/lib/security/java.security ../../../jdk/jre/lib/security/java.security.orig
            # Replace the java.security file with a revised copy
            cp ../../../was-ce/java_was-ce.security ../../../jdk/jre/lib/security/java.security
        fi
    fi
fi
# END: RLS 20170526 WI 71684 Enable Optim Manager to run with MD5 Java Security

# WASCE_JAVA_HOME_REPLACE is initialized by the installer as WASCE's java home
WASCE_JAVA_HOME="../../../jdk/jre"

# Ensure Geronimo settings are available when invoked stand-alone.
PRG="$0"
while [ -h "$PRG" ]; do
  ls=`ls -ld "$PRG"`
  link=`expr "$ls" : '.*-> \(.*\)$'`
  if expr "$link" : '.*/.*' > /dev/null; then
    PRG="$link"
  else
    PRG=`dirname "$PRG"`/"$link"
  fi
done
PRGDIR=`dirname "$PRG"`
if [ -z "$GERONIMO_HOME" ] ; then
  GERONIMO_HOME=`cd "$PRGDIR/.." ; pwd`
  export GERONIMO_HOME
fi
if [ -z "$GERONIMO_BASE" ] ; then
  GERONIMO_BASE="$GERONIMO_HOME"
  export GERONIMO_BASE
fi
if [ -z "$WASCE_HOME" ] ; then
  WASCE_HOME="$GERONIMO_HOME"
  export WASCE_HOME
fi

# Override JAVA/JRE home variables as required.
# First, look for a JVM relative to WASCE_JAVA_HOME.
if [ -n "$WASCE_JAVA_HOME" -a -x "$WASCE_JAVA_HOME"/bin/java ] ; then
  if [ -d "$WASCE_JAVA_HOME"/jre ]; then
    # is jdk
    JAVA_HOME="$WASCE_JAVA_HOME"
    JRE_HOME="$WASCE_JAVA_HOME"/jre
  else
    # is jre
    JAVA_HOME="$WASCE_JAVA_HOME"
    JRE_HOME="$WASCE_JAVA_HOME"
  fi
  export JAVA_HOME
  export JRE_HOME
# Otherwise, look for a private JVM relative to WASCE_HOME.
elif [ -d "$WASCE_HOME"/_jvm -a -x "$WASCE_HOME"/_jvm/bin/java ]; then
  if [ -d "$WASCE_HOME"/_jvm/jre ]; then
    # is jdk
    JAVA_HOME="$WASCE_HOME"/_jvm
    JRE_HOME="$WASCE_HOME"/_jvm/jre
  else
    # is jre
    JAVA_HOME="$WASCE_HOME"/_jvm
    JRE_HOME="$WASCE_HOME"/_jvm
  fi
  export JAVA_HOME
  export JRE_HOME
else 
  # Enforce required environment variables.
  if [ -z "$JAVA_HOME" -a -z "$JRE_HOME" ]; then
    echo "Neither the JAVA_HOME nor the JRE_HOME environment variable is defined."
    echo "At least one of these environment variable is needed to run this program."
    exit 1
  elif [ -z "$JAVA_HOME" -a -n "$JRE_HOME" ]; then
    JAVA_HOME="$JRE_HOME"
    export JAVA_HOME
  elif [ -n "$JAVA_HOME" -a -z "$JRE_HOME" ]; then
    if [ -d "$JAVA_HOME"/jre ]; then
      JRE_HOME="$JAVA_HOME"/jre
    else
      JRE_HOME="$JAVA_HOME"
    fi
    export JRE_HOME
  fi
  # Test java environment
  if [ ! -x "$JRE_HOME"/bin/java ]; then
    echo "Java environment is not correctly installed."
    exit 1
  fi
fi

